Learn R Programming

glmmsel (version 1.0.3)

predict.glmmsel: Predict function for glmmsel object

Description

Generates predictions for new data using a specified value of the regularisation parameter.

Usage

# S3 method for glmmsel
predict(object, x.new, cluster.new, lambda = NULL, ...)

Value

A matrix of predictions.

Arguments

object

an object of class glmmsel

x.new

a matrix of new values for the predictors

cluster.new

a vector identifying the clusters that the rows of x.new belong to

lambda

a value of the regularisation parameter

...

any other arguments

Author

Ryan Thompson <ryan.thompson-1@uts.edu.au>