glmmsel objectGenerates predictions for new data using a specified value of the regularisation parameter.
# S3 method for glmmsel
predict(object, x.new, cluster.new, lambda = NULL, ...)A matrix of predictions.
an object of class glmmsel
a matrix of new values for the predictors
a vector identifying the clusters that the rows of x.new belong to
a value of the regularisation parameter
any other arguments
Ryan Thompson <ryan.thompson-1@uts.edu.au>